pub struct WebSocketOptions {
pub ping_interval: Duration,
pub idle_timeout: Duration,
pub close_handshake_timeout: Duration,
pub incoming_queue_length: NonZeroUsize,
}Expand description
Configuration for WebSocket connections.
Fields
ping_interval: DurationInterval at which to send Ping frames.
We use pings for connection keep-alive.
Value must be smaller than idle_timeout.
Default: 15s
idle_timeout: DurationAmount of time after which an idle connection is closed.
A connection is considered idle if no data is received nor sent.
This includes Ping/Pong frames used for keep-alive.
Value must be greater than ping_interval.
Default: 30s
close_handshake_timeout: DurationFor how long to keep draining the incoming messages until a client close is received.
Default: 250ms
incoming_queue_length: NonZeroUsizeMaximum number of messages to queue for processing.
If this number is exceeded, the client is disconnected.
Default: 2048